/*
The software in this package is distributed under the GNU General
Public License version 2 (with a special exception described below).

A copy of GNU General Public License (GPL) is included in this distribution,
in the file COPYING.GPL.

As a special exception, if other files instantiate templates or use macros
or inline functions from this file, or you compile this file and link it
with other works to produce a work based on this file, this file
does not by itself cause the resulting work to be covered
by the GNU General Public License.

However the source code for this file must still be made available
in accordance with section (3) of the GNU General Public License.

This exception does not invalidate any other reasons why a work based
on this file might be covered by the GNU General Public License.
*/
#ifndef HOST_ADDRESS_H
#define HOST_ADDRESS_H

#include <stdint.h>

#include <list>

#include <boost/asio.hpp>

#include "dns/timetolive.h"

//-----------------------------------------------------------------------------
// HostAddress
//-----------------------------------------------------------------------------

class HostAddress
{
public:
    HostAddress();
    HostAddress(
            const boost::asio::ip::address &ip,
            uint32_t ttl
    );
    ~HostAddress();

    boost::asio::ip::address get_ip() const;
    void set_ip( const boost::asio::ip::address &ip );

    TimeToLive get_ttl() const;
    void set_ttl( const TimeToLive &ttl );

private:
    /// IP address of the host
    boost::asio::ip::address Ip;
    /// time-to-live of the host IP
    TimeToLive Ttl;

};

//-----------------------------------------------------------------------------
// HostAddressList
//-----------------------------------------------------------------------------

typedef std::list<HostAddress> HostAddressList;

#endif // HOST_ADDRESS_H
