/*
 The software in this package is distributed under the GNU General
 Public License version 2 (with a special exception described below).

 A copy of GNU General Public License (GPL) is included in this distribution,
 in the file COPYING.GPL.

 As a special exception, if other files instantiate templates or use macros
 or inline functions from this file, or you compile this file and link it
 with other works to produce a work based on this file, this file
 does not by itself cause the resulting work to be covered
 by the GNU General Public License.

 However the source code for this file must still be made available
 in accordance with section (3) of the GNU General Public License.

 This exception does not invalidate any other reasons why a work based
 on this file might be covered by the GNU General Public License.
 */

#ifndef TCP_SEGMENT_H
#define TCP_SEGMENT_H

#include <iostream>

#include <boost/asio.hpp>
#include <boost/shared_ptr.hpp>
#include <boost/utility.hpp>

//-----------------------------------------------------------------------------
// TcpSegment
//-----------------------------------------------------------------------------

/**
 * @brief Abstract class for TCP Segments.
 */
class TcpSegment : boost::noncopyable
{
public:
    virtual bool match_rst_reply(
            const boost::asio::ip::address &source_address
    ) const = 0;

    virtual void print_rst_reply(
            const boost::posix_time::ptime &time_packet_sent
    ) const = 0;

    virtual bool match_syn_ack_reply(
            const boost::asio::ip::address &source_address
    ) const = 0;

    virtual void print_syn_ack_reply(
            const boost::posix_time::ptime &time_packet_sent
    ) const = 0;

    virtual bool read( std::istream &is ) = 0;
    virtual bool write( std::ostream &os ) const = 0;

protected:
    TcpSegment();
    virtual ~TcpSegment();

};

//-----------------------------------------------------------------------------
// TcpSegmentItem
//-----------------------------------------------------------------------------

typedef boost::shared_ptr<TcpSegment> TcpSegmentItem;

#endif // TCP_SEGMENT_H
